1.x
===

.. include:: ../full_changelog_explanation.rst
.. include:: ../summary_explanation.rst

.. toctree::
   :maxdepth: 2

   1.9/index
   1.8/index
   1.7/index
   1.6/index

Ticket numbers are almost can be internal to Logilab, or from bitbucket. In latest
version it's also github issues.

.. toctree::
   :maxdepth: 2

   1.5.rst
   1.4.rst
   1.3.rst
   1.2.rst
   1.1.rst
   1.0.rst
